@@ -25,16 +25,21 @@
     "natbib"
     "hyperref")
    (LaTeX-add-labels
-    "sec:org9882d46"
-    "sec:org9adc575"
-    "sec:orga68020b"
-    "sec:org6fdc184"
+    "sec:org288fce5"
+    "sec:orgb2db2dc"
+    "sec:orgb12f392"
+    "sec:orgff243e0"
     "sec:macros-citations"
-    "sec:org64e04c3"
-    "sec:changing-style-refer"
-    "sec:org8cc6961"
-    "sec:org9d8ff4c"
-    "sec:orgb3a9b6e"
-    "sec:org1f3fc7c"))
+    "sec:org2098c9b"
+    "sec:orgc23fd8d"
+    "sec:org23ed409"
+    "sec:org07ff283"
+    "sec:org6b16cbc"
+    "org50e22be"
+    "sec:orge2b9228")
+   (LaTeX-add-environments
+    '("eptblFigure" LaTeX-env-args ["argument"] 0)
+    '("epfigFigure" LaTeX-env-args ["argument"] 0)
+    '("epFigure" LaTeX-env-args ["argument"] 0)))
  :latex)
 
